@@ -1,15 +1,14 @@
 #!/bin/sh
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: regex-tdfa
-version: 1.2.1
-id: regex-tdfa-1.2.1-506e9a407febb132e40b4c629d403ead
-key: regex_IJTo8JfTqsQ7Vol2eJqmYC
+version: 1.2.2
+id: regex-tdfa-1.2.2-356f1fd0d011fc4d4ac3ea6a1e65b0ca
+key: regex_J3z6tWCVrdJDJFi6mr8nNE
 license: BSD3
 copyright: Copyright (c) 2007, Christopher Kuklewicz
-maintainer: TextRegexLazy@personal.mightyreason.com
+maintainer: Artyom <yom@artyom.me>, Christopher Kuklewicz <TextRegexLazy@personal.mightyreason.com>
 stability: Seems to work, but not POSIX yet
-homepage: http://hackage.haskell.org/package/regex-tdfa
-package-url: http://code.haskell.org/regex-tdfa/
+homepage: https://github.com/ChrisKuklewicz/regex-tdfa
 synopsis: Replaces/Enhances Text.Regex
 description:
     A new all Haskell "tagged" DFA regex engine, inspired by libtre
@@ -30,10 +29,10 @@ exposed-modules:
     Text.Regex.TDFA.TDFA Text.Regex.TDFA.TNFA
 hidden-modules: Paths_regex_tdfa
 trusted: False
-import-dirs: /usr/lib/ghc-7.10.3/site-local/regex-tdfa-1.2.1
-library-dirs: /usr/lib/ghc-7.10.3/site-local/regex-tdfa-1.2.1
-data-dir: /usr/share/arm-linux-ghc-7.10.3/regex-tdfa-1.2.1
-hs-libraries: HSregex-tdfa-1.2.1-IJTo8JfTqsQ7Vol2eJqmYC
+import-dirs: /usr/lib/ghc-7.10.3/site-local/regex-tdfa-1.2.2
+library-dirs: /usr/lib/ghc-7.10.3/site-local/regex-tdfa-1.2.2
+data-dir: /usr/share/arm-linux-ghc-7.10.3/regex-tdfa-1.2.2
+hs-libraries: HSregex-tdfa-1.2.2-J3z6tWCVrdJDJFi6mr8nNE
 depends:
     array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
